@@ -1,6 +1,6 @@
 import importlib.metadata
 import importlib.util
-
+import os
 from os import listdir
 from os.path import join, isdir, exists, isfile
 from django.contrib import admin
@@ -123,4 +123,7 @@ if len(filtered_current_path) > 0:
                     except Exception as e:
                         import traceback
                         traceback.print_exc()
-                        continue
\ No newline at end of file
+                        continue
+
+if os.environ.get('IS_LAN', 'false') == 'true':
+    views.init_bomiot()
\ No newline at end of file
